@@ -116,7 +116,7 @@ def support():
 @main.command(short_help="Generates the necessary files for a new PreTeXt project.", 
     context_settings=CONTEXT_SETTINGS)
 @click.argument('template', default='book',
-              type=click.Choice(['book', 'article', 'hello'], case_sensitive=False))
+              type=click.Choice(['book', 'article', 'hello', 'slideshow'], case_sensitive=False))
 @click.option('-d', '--directory', type=click.Path(), default='new-pretext-project',
               help="Directory to create/use for the project.")
 @click.option('-u', '--url-template', type=click.STRING,
@@ -288,6 +288,7 @@ def build(target, format, source, output, stringparam, xsl, publication, clean,
     target = project.target(name=target_name)
     if target is None:
         log.critical("Build target could not be found in project.ptx manifest.")
+        log.critical(f"Possible build targets are: {project.target_names()}")
         log.critical("Exiting without completing task.")
         return
     if generate=='ALL':
